# COST02: How do you govern usage?

## References

- [AWS COST02](https://docs.aws.amazon.com/wellarchitected/latest/framework/cost-02.html)

## Date

2025-11-27

## Focus Area

Expenditure and Usage Awareness

## Best Practices

### COST02-BP01: Develop policies based on organization requirements
Cost policies.

### COST02-BP02: Implement goals and targets
Cost targets.

### COST02-BP03: Implement an account structure
Account structure for cost allocation.

### COST02-BP04: Implement groups and roles
Access control.

### COST02-BP05: Implement cost controls
Budgets, alerts.

### COST02-BP06: Track project lifecycle
Resource lifecycle.

## Checklist

- [ ] Cost policies defined
- [ ] Cost targets set
- [ ] Account structure organized
- [ ] Cost controls implemented
